pub enum CreateSimulationApplicationError {
IdempotentParameterMismatch(String),
InternalServer(String),
InvalidParameter(String),
LimitExceeded(String),
ResourceAlreadyExists(String),
Throttling(String),
}Expand description
Errors returned by CreateSimulationApplication
Variants
IdempotentParameterMismatch(String)
The request uses the same client token as a previous, but non-identical request. Do not reuse a client token with different requests, unless the requests are identical.
InternalServer(String)
AWS RoboMaker experienced a service issue. Try your call again.
InvalidParameter(String)
A parameter specified in a request is not valid, is unsupported, or cannot be used. The returned message provides an explanation of the error value.
LimitExceeded(String)
The requested resource exceeds the maximum number allowed, or the number of concurrent stream requests exceeds the maximum number allowed.
ResourceAlreadyExists(String)
The specified resource already exists.
Throttling(String)
AWS RoboMaker is temporarily unable to process the request. Try your call again.
Implementations