pub struct CreateSimulationApplicationRequest {
pub name: String,
pub rendering_engine: Option<RenderingEngine>,
pub robot_software_suite: RobotSoftwareSuite,
pub simulation_software_suite: SimulationSoftwareSuite,
pub sources: Vec<SourceConfig>,
pub tags: Option<HashMap<String, String>>,
}Fields
name: StringThe name of the simulation application.
rendering_engine: Option<RenderingEngine>The rendering engine for the simulation application.
robot_software_suite: RobotSoftwareSuiteThe robot software suite (ROS distribution) used by the simulation application.
simulation_software_suite: SimulationSoftwareSuiteThe simulation software suite used by the simulation application.
sources: Vec<SourceConfig>The sources of the simulation application.
A map that contains tag keys and tag values that are attached to the simulation application.