pub struct CreateSimulationApplicationVersionResponse {
pub arn: Option<String>,
pub last_updated_at: Option<f64>,
pub name: Option<String>,
pub rendering_engine: Option<RenderingEngine>,
pub revision_id: Option<String>,
pub robot_software_suite: Option<RobotSoftwareSuite>,
pub simulation_software_suite: Option<SimulationSoftwareSuite>,
pub sources: Option<Vec<Source>>,
pub version: Option<String>,
}Fields
arn: Option<String>The Amazon Resource Name (ARN) of the simulation application.
last_updated_at: Option<f64>The time, in milliseconds since the epoch, when the simulation application was last updated.
name: Option<String>The name of the simulation application.
rendering_engine: Option<RenderingEngine>The rendering engine for the simulation application.
revision_id: Option<String>The revision ID of the simulation application.
robot_software_suite: Option<RobotSoftwareSuite>Information about the robot software suite (ROS distribution).
simulation_software_suite: Option<SimulationSoftwareSuite>The simulation software suite used by the simulation application.
sources: Option<Vec<Source>>The sources of the simulation application.
version: Option<String>The version of the simulation application.